@@ -19,6 +19,7 @@ class Api():
     def __init__(self,
                  BASE_URL: str = "https://nhentai.net",
                  BASE_IMG: str = "https://i.nhentai.net/galleries",
+                 BASE_THUMBNAIL: str = "https://t.nhentai.net/galleries",
                  BASE_PURURIN: str = "https://scathach.redsplit.org/v4/pururin/",
                  BASE_NHENTAI_UNBLOCK: str = "https://nhentai.sinxdr.workers.dev",
                  BASE_HENTAIFOX: str = "https://scathach.redsplit.org/v4/hentaifox/",
@@ -26,6 +27,7 @@ class Api():
 
         self.api = BASE_URL
         self.img = BASE_IMG
+        self.thumbnail = BASE_THUMBNAIL
         self.pururin = BASE_PURURIN
         self.hentaifox = BASE_HENTAIFOX
         self.hentai2read = BASE_HENTAI2READ
@@ -208,15 +210,15 @@ def parser(obj: dict):
     for image in raw_object['images']['pages']:
         if image['t'] == 'p':
             thumbnail_urls.append(
-                f'{BASE_URL.img}/{media}/{len(thumbnail_urls) + 1}t.png')
+                f'{BASE_URL.thumbnail}/{media}/{len(thumbnail_urls) + 1}t.png')
 
         elif image['t'] == 'j':
             thumbnail_urls.append(
-                f'{BASE_URL.img}/{media}/{len(thumbnail_urls) + 1}t.jpg')
+                f'{BASE_URL.thumbnail}/{media}/{len(thumbnail_urls) + 1}t.jpg')
 
         elif image['t'] == 'g':
             thumbnail_urls.append(
-                f'{BASE_URL.img}/{media}/{len(thumbnail_urls) + 1}t.gif')
+                f'{BASE_URL.thumbnail}/{media}/{len(thumbnail_urls) + 1}t.gif')
 
     book_object['thumbnail_urls'] = thumbnail_urls
     return better_object(book_object)
